pub struct ResolvedBinary {
pub krate: ResolvedCrate,
pub provider: BinaryProvider,
pub path: PathBuf,
pub target: String,
}Expand description
A resolved binary is a pre-built executable that cgx found and prepared, so the crate can run without being built from source.
This type is the result of resolving a ResolvedCrate.
Fields
krate: ResolvedCrateThe crate for which this binary was resolved
provider: BinaryProviderFrom what binary provider this binary was obtained
path: PathBufPath to the executable cgx should run
target: StringThe target this binary was published for.
In most cases this is just the host’s target, but there are many edge cases where a prebuilt binary will be published for a target that doesn’t match the host’s target but is compatible with the host (the most common is a musl linux binary used on a glibc linux host).