BuildOptionsArgs

Struct BuildOptionsArgs 

pub struct BuildOptionsArgs {
    pub features: Option<String>,
    pub all_features: bool,
    pub no_default_features: bool,
    pub profile: Option<String>,
    pub debug: bool,
    pub target: Option<String>,
    pub jobs: Option<usize>,
    pub ignore_rust_version: bool,
    pub bin: Option<String>,
    pub example: Option<String>,
}
CLI arguments that are crate-specific and passed through to cargo build.

These args are segreated from the other CLI args to make the semantic distinction more explicit. Most CLI args can also be set in config files to apply globally, but these are always crate-specific.

Fields

features: Option<String>

Space or comma separated list of features to activate

all_features: bool

Activate all available features

no_default_features: bool

Do not activate the default features

profile: Option<String>

Build with the specified profile

debug: bool

Build in debug mode (with the ‘dev’ profile) instead of release mode

target: Option<String>

Build for the target triple

jobs: Option<usize>

Number of parallel jobs, defaults to # of CPUs

ignore_rust_version: bool

Ignore rust-version specification in packages

bin: Option<String>

Install only the specified binary

example: Option<String>

Install only the specified example