pub struct ConfigFile {Show 13 fields
pub bin_dir: Option<PathBuf>,
pub build_dir: Option<PathBuf>,
pub cache_dir: Option<PathBuf>,
pub locked: Option<bool>,
pub log_level: Option<String>,
pub offline: Option<bool>,
pub resolve_cache_timeout: Option<Duration>,
pub toolchain: Option<String>,
pub default_registry: Option<String>,
pub prebuilt_binaries: Option<PrebuiltBinariesConfig>,
pub http: Option<HttpConfigFile>,
pub tools: Option<HashMap<String, ToolConfig>>,
pub aliases: Option<HashMap<String, String>>,
}Expand description
Intermediate structure for deserializing config files from TOML.
This matches the structure of cgx.toml files and is used during the deserialization
process. Fields are then mapped to the final Config struct.
Fields
bin_dir: Option<PathBuf>build_dir: Option<PathBuf>cache_dir: Option<PathBuf>locked: Option<bool>log_level: Option<String>offline: Option<bool>resolve_cache_timeout: Option<Duration>toolchain: Option<String>default_registry: Option<String>prebuilt_binaries: Option<PrebuiltBinariesConfig>http: Option<HttpConfigFile>tools: Option<HashMap<String, ToolConfig>>aliases: Option<HashMap<String, String>>Implementations
Sourceimpl ConfigFile
impl ConfigFile
Sourcepub fn base_config() -> Self
pub fn base_config() -> Self
Returns the base configuration with sensible defaults.
This is distinct from Default which returns all None values. The Default impl
is used by serde to represent fields missing from a config file, so it must be all None.
This method provides the actual default values that serve as the lowest-precedence layer in the config hierarchy, before any config files are applied.