pub enum Forge {
GitHub {
custom_url: Option<Url>,
owner: String,
repo: String,
},
GitLab {
custom_url: Option<Url>,
owner: String,
repo: String,
},
}Expand description
Supported software forges where crates can be hosted
Variants
Implementations
Sourceimpl Forge
impl Forge
Sourcepub fn repo_url(&self) -> String
pub fn repo_url(&self) -> String
The HTTPS URL to the repository root (no .git suffix).
This is the URL that is intended for humans to view to look at the repo in a browser.
This is also typically what would be placed in the Cargo.toml repository field for a
crate.
Use this for API and release URLs. Use Forge::git_url when a
.git-suffixed clone URL is needed.
Sourcepub fn try_parse_from_url(git_url: &str) -> Option<Self>
pub fn try_parse_from_url(git_url: &str) -> Option<Self>
Attempt to parse a URL into a reference to a repo in a forge
When a known forge like Github or Gitlab is used, treating it as a forge as opposed to a generic Git URL is important because we can use that forge’s API to look for binary releases for the crate, which if found will dramatically speed up installation.
Only HTTPS urls are recognized, and only URLs that point to the root of a repository, on the forges that we have API support for.