Module git

Module git 

Git operations for cgx

This module implements a two-tier git caching system inspired by cargo:

  1. Git database cache (bare repositories) - one per URL
  2. Git checkout cache (working trees) - one per commit

This architecture enables:

  • Targeted refspec fetches which can be much more efficient for large repos
  • Warm cache reuse when multiple commits from the same repo are used over time
  • Correct handling of submodules, filters, and line endings via native gix checkout

Enums

GitSelector
Git reference selector for fetching specific refs.