pub enum GitMessage {
ResolvingRef {
url: String,
selector: GitSelector,
},
RefFoundLocally {
url: String,
selector: GitSelector,
commit: String,
},
FetchingRepo {
url: String,
selector: GitSelector,
},
ResolvedRef {
commit: String,
},
CheckingOut {
commit: String,
path: PathBuf,
},
CheckoutComplete {
path: PathBuf,
},
CheckoutExists {
commit: String,
path: PathBuf,
},
}Expand description
Messages related to git operations.
Variants
ResolvingRef
About to check if the ref exists in the local bare repo
RefFoundLocally
The ref was already present in the local bare repo (no fetch needed)
FetchingRepo
Starting a network fetch because the ref was not present locally
ResolvedRef
The ref was resolved to a commit (only emitted after fetching)
CheckingOut
Extracting a working tree from the bare repo
CheckoutComplete
Extraction completed (only emitted after CheckingOut)
CheckoutExists
The checkout directory already exists (no extraction needed)
Implementations
Sourceimpl GitMessage
impl GitMessage
pub fn resolving_ref(url: &str, selector: &GitSelector) -> Self
pub fn ref_found_locally( url: &str, selector: &GitSelector, commit: &str, ) -> Self
pub fn fetching_repo(url: &str, selector: &GitSelector) -> Self
pub fn resolved_ref(commit: &str) -> Self
pub fn checking_out(commit: &str, path: &Path) -> Self
pub fn checkout_complete(path: &Path) -> Self
pub fn checkout_exists(commit: &str, path: &Path) -> Self