pub enum CrateSpec {
CratesIo {
name: String,
version: Option<VersionReq>,
},
Registry {
source: RegistrySource,
name: String,
version: Option<VersionReq>,
},
Git {
repo: String,
selector: GitSelector,
name: Option<String>,
version: Option<VersionReq>,
},
Forge {
forge: Forge,
selector: GitSelector,
name: Option<String>,
version: Option<VersionReq>,
},
LocalDir {
path: PathBuf,
name: Option<String>,
version: Option<VersionReq>,
},
}Expand description
A specification of a crate that the user wants to execute.
Note that “crate” here doesn’t necessarily mean “crate on Crates.io”. We support various ways of referring to a crate to run, which is why this enum type is needed. It abstracts away the various ways the user might specify a crate to run. Ultimately all of these need to be resolved to a path in the local filesystem, controlled by cgx, from which we can build and run.
Versioning
For crate specs that point to registries (which store multiple versions of a crate), the default is to choose the latest version. If a version is specified, then the most recent version that matches the specification is chosen. If no such version exists then an error occurs.
For crate specs that point to local paths, forges, or git repos, there is no choice of
version; the version of the crate is whatever it is at the specified location. In those cases,
if the version field is present, it is validated against the version found at the location,
and if it’s not compatible then an error occurs.
Variants
CratesIo
A crate on Crates.io, specified by its name and optional version.
Registry
A crate on some other registry, specified by its name and optional version.
Fields
source: RegistrySourceThe registry source (either a named registry or a direct index URL)
version: Option<VersionReq>Git
A crate in a git repository, specified by the repository URL and optional branch, tag, or commit hash.
The name field is optional. If omitted, it will be discovered from the repository
(which must contain exactly one crate). If the repository contains multiple crates,
the name must be specified.
If the version field is present, the crate found at the specified repo must have a
version that is compatible with the version specification or an error occurs.
Forge
A crate in a repo in some software Forge, specified by its repo, optional path within that repo, and optional branch, tag, or commit hash.
The name field is optional. If omitted, it will be discovered from the repository
(which must contain exactly one crate). If the repository contains multiple crates,
the name must be specified.
Fields
selector: GitSelectorA branch, tag, or commit hash within the repository
version: Option<VersionReq>LocalDir
A crate in a local directory, specified by the path to the directory containing the crate’s
Cargo.toml or a workspace Cargo.toml to which the crate belongs.
The name field is optional. If omitted, it will be discovered from the path
(which must contain exactly one crate). If the path contains multiple crates
(i.e., a workspace), the name must be specified.
Implementations
Sourceimpl CrateSpec
impl CrateSpec
Sourcepub fn load(config: &Config, req: &CrateRequest) -> Result<Self>
pub fn load(config: &Config, req: &CrateRequest) -> Result<Self>
Resolve a CrateRequest into a CrateSpec, respecting config-based overrides.
This method applies config-based transformations and overrides:
- Alias resolution: Maps short names to full crate names (e.g.,
rg->ripgrep) - Tool pinning: Applies version pinning from config for known tools
- Default registry: Uses config’s default registry when no registry specified
Priority order for version selection:
- The user’s explicitly specified version requirement in
CrateRequest::version - Config tool pinning
- Current/latest version of the crate at whatever source is being used
Sourcepub fn configured_tool_name(&self) -> Option<&str>
pub fn configured_tool_name(&self) -> Option<&str>
Get the crate name used for looking up the crate in the [tools] TOML section,
if one is known.
Not all CrateSpec variants have a known crate name; for those variants, unfortunately,
the contents of the [tools] section cannot be used to configure them, and this method
returns None.